(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     75242,       1433]
NotebookOptionsPosition[     75700,       1425]
NotebookOutlinePosition[     76135,       1444]
CellTagsIndexPosition[     76092,       1441]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Shear Flow of a Section\n",
 StyleBox["Mengtian Yin, Baoxing Xu \nUniversity of Virginia, 2019-05-28",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center,
 ExpressionUUID -> "48f79e31-b1b6-491d-b1fe-0de1a293c5af"],

Cell[TextData[{
 "\nShear stress in a member can be determined with shear formula, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Tau]", "=", 
    FractionBox["VQ", 
     RowBox[{"I", " ", "t"}]]}], TraditionalForm]]],
 ", where V is the shear force applied on the section, Q =  y\:0305\
\[CloseCurlyQuote]A\[CloseCurlyQuote],  where A\[CloseCurlyQuote] is the area \
of the top (or bottom) portion of the member\[CloseCurlyQuote]s cross \
section, above (or below) the section plane where t is measured, and y\:0305\
\[CloseCurlyQuote] is the distance from the neutral axis to the centroid of A\
\[CloseCurlyQuote], I is the moment of inertia of the entire cross section, t \
is the thickness of the cross section at the point where tau is measured. \n\
In this module, four composite sections are presented with height, width, and \
thickness changeable. For the first three sections, thickness is assumed to \
be uniform. For the hollow circle, height is the outer diameter and thickness \
is the inner diameter. For each of them, shear force V is assumed to be \
applied to the negative y direction, i.g. downward, on the whole \
cross-section simultaneously. With the red A-A plane moving either \
horizontally or vertically, the distribution of shear stress ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Tau]", "xz"], TraditionalForm]]],
 " will be plotted.\n"
}], "Text",
 ExpressionUUID -> "1035f020-41a2-44ee-9dfe-060d95202890"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`length1$$ = 1, $CellContext`length2$$ = 
    1, $CellContext`length3$$ = 1, $CellContext`length4$$ = 
    0.5, $CellContext`moi$$ = 1, $CellContext`opa0$$ = 
    0, $CellContext`opaf$$ = 1, $CellContext`orientation$$ = 
    Vertical, $CellContext`poc$$ = 
    1, $CellContext`posh$$ = -0.9, $CellContext`posv$$ = -0.9, \
$CellContext`sectiontype$$ = 1, $CellContext`thickness1$$ = 
    0.1, $CellContext`thickness2$$ = 0.1, $CellContext`thickness3$$ = 
    0.1, $CellContext`thickness4$$ = 0.2, $CellContext`V$$ = 
    3, $CellContext`width1$$ = 1, $CellContext`width2$$ = 
    1, $CellContext`width3$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`opa0$$], 0, 
       Row[{"Coordinates visibility", 
         Spacer[30]}]}, {1 -> "On", 0 -> "off"}}, {{
       Hold[$CellContext`sectiontype$$], 1, ""}, {
      1 -> "1", 2 -> "2", 3 -> "3", 4 -> "4"}}, {{
       Hold[$CellContext`length1$$], 1, 
       Row[{"Length [m]", 
         Spacer[63]}]}, 0.3, 1}, {{
       Hold[$CellContext`width1$$], 1, 
       Row[{"Height [m]", 
         Spacer[63]}]}, 0.3, 1}, {{
       Hold[$CellContext`length2$$], 1, 
       Row[{"Length [m]", 
         Spacer[63]}]}, 0.3, 1}, {{
       Hold[$CellContext`width2$$], 1, 
       Row[{"Height [m]", 
         Spacer[63]}]}, 0.3, 1}, {{
       Hold[$CellContext`length3$$], 1, 
       Row[{"Length [m]", 
         Spacer[63]}]}, 0.3, 1}, {{
       Hold[$CellContext`width3$$], 1, 
       Row[{"Height [m]", 
         Spacer[63]}]}, 0.3, 1}, {{
       Hold[$CellContext`length4$$], 0.5, 
       Row[{"Outer Radius [m]", 
         Spacer[30]}]}, 0.3, 0.5}, {{
       Hold[$CellContext`thickness1$$], 0.1, 
       Row[{"Thickness [m]", 
         Spacer[48]}]}, 0.05, 0.1}, {{
       Hold[$CellContext`thickness2$$], 0.1, 
       Row[{"Thickness [m]", 
         Spacer[48]}]}, 0.05, 0.1}, {{
       Hold[$CellContext`thickness3$$], 0.1, 
       Row[{"Thickness [m]", 
         Spacer[48]}]}, 0.05, 0.1}, {{
       Hold[$CellContext`thickness4$$], 0.2, 
       Row[{"Inner Radius [m]", 
         Spacer[34]}]}, 0.05, 0.2}, {{
       Hold[$CellContext`V$$], 3, 
       Row[{"Magnitude of shear force", 
         Spacer[25]}]}, 0.1, 8}, {{
       Hold[$CellContext`orientation$$], Vertical, 
       Text[
        Style[
        "\!\(\*\nStyleBox[\"Orientation\",\nFontWeight->\"Bold\"]\)", 12]]}, {
      Vertical, Horizontal}}, {{
       Hold[$CellContext`opaf$$], 1, 
       Row[{
        "\!\(\*\nStyleBox[\"Shear\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"Force\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"Diagram\",\nFontWeight->\"Bold\"]\)", 
         Spacer[10]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`posv$$], -0.9, 
       Row[{"Position of AA Plane", 
         Spacer[48]}]}, -1, 1}, {{
       Hold[$CellContext`posh$$], -0.9, 
       Row[{"Position of AA Plane", 
         Spacer[34]}]}, -1, 1, 0.01}, {{
       Hold[$CellContext`poc$$], 1, 
       Row[{
        "\!\(\*\nStyleBox[\"Position\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"of\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"Centroid\",\nFontWeight->\"Bold\"]\)", 
         Spacer[10]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`moi$$], 1, 
       Row[{
        "\!\(\*\nStyleBox[\"Moment\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"of\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"Inertia\",\nFontWeight->\"Bold\"]\)", 
         Spacer[19]}]}, {1 -> "On", 0 -> "Off"}}, {
      Hold[
       Grid[{{
          Manipulate`Place[1]}, {
          Style[
          "\!\(\*\nStyleBox[\"Select\",\nFontFamily->\"Arial\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontFamily->\"Arial\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"section\",\nFontFamily->\"Arial\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontFamily->\"Arial\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"type\",\n\
FontFamily->\"Arial\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 10]}, {
          Dynamic[$CellContext`im1, SynchronousUpdating -> False]}, {
          Manipulate`Place[2]}, {
          PaneSelector[{1 -> Column[{
               Manipulate`Place[3], 
               Manipulate`Place[4]}], 2 -> Column[{
               Manipulate`Place[5], 
               Manipulate`Place[6]}], 3 -> Column[{
               Manipulate`Place[7], 
               Manipulate`Place[8]}], 4 -> Column[{
               Manipulate`Place[9]}]}, 
           Dynamic[$CellContext`sectiontype$$]]}, {
          PaneSelector[{1 -> Column[{
               Manipulate`Place[10]}], 2 -> Column[{
               Manipulate`Place[11]}], 3 -> Column[{
               Manipulate`Place[12]}], 4 -> Column[{
               Manipulate`Place[13]}]}, 
           Dynamic[$CellContext`sectiontype$$]]}, {
          Manipulate`Place[14]}, {
          Manipulate`Place[15]}, {
          Manipulate`Place[16]}, {
          PaneSelector[{Vertical -> Column[{
               Manipulate`Place[17]}], Horizontal -> Column[{
               Manipulate`Place[18]}]}, 
           Dynamic[$CellContext`orientation$$]]}, {
          Manipulate`Place[19]}, {
          Row[{
            Dynamic[
             If[$CellContext`poc$$ == 1, $CellContext`temp1, 
              Invisible[$CellContext`temp1]]]}]}, {
          Manipulate`Place[20]}, {
          Row[{
            Dynamic[
             If[$CellContext`moi$$ == 1, $CellContext`temp2, 
              Invisible[$CellContext`temp2]]]}]}}, Frame -> True, FrameStyle -> 
        Thickness[Tiny], Alignment -> Left, Spacings -> {Automatic, 1.5}]], 
      Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = {
    500., {316.5, 322.5}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`opa0$28263$$ = 
    False, $CellContext`sectiontype$28264$$ = 
    False, $CellContext`length1$28265$$ = 0, $CellContext`width1$28266$$ = 
    0, $CellContext`length2$28267$$ = 0, $CellContext`width2$28268$$ = 
    0, $CellContext`length3$28269$$ = 0, $CellContext`width3$28270$$ = 
    0, $CellContext`length4$28271$$ = 0, $CellContext`thickness1$28272$$ = 
    0, $CellContext`thickness2$28273$$ = 0, $CellContext`thickness3$28274$$ = 
    0, $CellContext`orientation$28275$$ = False, $CellContext`opaf$28276$$ = 
    False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`length1$$ = 1, $CellContext`length2$$ = 
        1, $CellContext`length3$$ = 1, $CellContext`length4$$ = 
        0.5, $CellContext`moi$$ = 1, $CellContext`opa0$$ = 
        0, $CellContext`opaf$$ = 1, $CellContext`orientation$$ = 
        Vertical, $CellContext`poc$$ = 
        1, $CellContext`posh$$ = -0.9, $CellContext`posv$$ = -0.9, \
$CellContext`sectiontype$$ = 1, $CellContext`thickness1$$ = 
        0.1, $CellContext`thickness2$$ = 0.1, $CellContext`thickness3$$ = 
        0.1, $CellContext`thickness4$$ = 0.2, $CellContext`V$$ = 
        3, $CellContext`width1$$ = 1, $CellContext`width2$$ = 
        1, $CellContext`width3$$ = 1}, "ControllerVariables" :> {
        Hold[$CellContext`opa0$$, $CellContext`opa0$28263$$, False], 
        Hold[$CellContext`sectiontype$$, $CellContext`sectiontype$28264$$, 
         False], 
        Hold[$CellContext`length1$$, $CellContext`length1$28265$$, 0], 
        Hold[$CellContext`width1$$, $CellContext`width1$28266$$, 0], 
        Hold[$CellContext`length2$$, $CellContext`length2$28267$$, 0], 
        Hold[$CellContext`width2$$, $CellContext`width2$28268$$, 0], 
        Hold[$CellContext`length3$$, $CellContext`length3$28269$$, 0], 
        Hold[$CellContext`width3$$, $CellContext`width3$28270$$, 0], 
        Hold[$CellContext`length4$$, $CellContext`length4$28271$$, 0], 
        Hold[$CellContext`thickness1$$, $CellContext`thickness1$28272$$, 0], 
        Hold[$CellContext`thickness2$$, $CellContext`thickness2$28273$$, 0], 
        Hold[$CellContext`thickness3$$, $CellContext`thickness3$28274$$, 0], 
        Hold[$CellContext`orientation$$, $CellContext`orientation$28275$$, 
         False], 
        Hold[$CellContext`opaf$$, $CellContext`opaf$28276$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`size$, $CellContext`opa1$, $CellContext`opa2$, \
$CellContext`opa3$, $CellContext`opa4$, $CellContext`opa5$, \
$CellContext`opa6$, $CellContext`opa7$, $CellContext`opa8$, \
$CellContext`dwf0$, $CellContext`dwf1$, $CellContext`dwf2$, \
$CellContext`dwf3$, $CellContext`dwf4$, $CellContext`dwf5$, \
$CellContext`dwf6$, $CellContext`dwf7$, $CellContext`dwf8$, \
$CellContext`dwf9$}, $CellContext`size$ = 1; $CellContext`newx = 
         0; $CellContext`newy = 0; $CellContext`im1 = Image[
           Image[CompressedData["
1:eJzt3b1uM0l2BmD5J3DozJECX4MSg5kzOV3DmZJdeLhwIgOzCxjO9hKY+U54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            "], "Byte", ColorSpace -> "RGB", Interleaving -> True], ImageSize -> 
           280]; If[$CellContext`sectiontype$$ == 1, $CellContext`opa1$ = 
          1, $CellContext`opa1$ = 0]; 
        If[$CellContext`sectiontype$$ == 2, $CellContext`opa2$ = 
          1, $CellContext`opa2$ = 0]; 
        If[$CellContext`sectiontype$$ == 3, $CellContext`opa3$ = 
          1, $CellContext`opa3$ = 0]; 
        If[$CellContext`sectiontype$$ == 4, $CellContext`opa4$ = 
          1, $CellContext`opa4$ = 0]; 
        If[$CellContext`orientation$$ == Vertical, $CellContext`opa1l = 1]; 
        If[$CellContext`orientation$$ == Horizontal, $CellContext`opa1l = 
          0]; $CellContext`cx1 = 0; $CellContext`cy1 = 
         0; $CellContext`cx11 = -$CellContext`newy; $CellContext`cy11 = \
-$CellContext`newx; $CellContext`cx2 = 
         0; $CellContext`cy2 = ((($CellContext`width2$$/
               2 - $CellContext`thickness2$$/
              2) $CellContext`thickness2$$) $CellContext`length2$$ - \
(($CellContext`width2$$/
              2 - ($CellContext`width2$$ - $CellContext`thickness2$$)/
             2) $CellContext`thickness2$$) ($CellContext`width2$$ - \
$CellContext`thickness2$$))/($CellContext`thickness2$$ $CellContext`length2$$ + \
$CellContext`thickness2$$ ($CellContext`width2$$ - \
$CellContext`thickness2$$)); $CellContext`cx22 = -$CellContext`newy; \
$CellContext`cy22 = -$CellContext`newx; $CellContext`cx3 = 
         0; $CellContext`cy3 = 
         0; $CellContext`cx33 = -$CellContext`newy; $CellContext`cy33 = \
-$CellContext`newx; $CellContext`cx4 = 0; $CellContext`cy4 = 
         0; $CellContext`cx44 = -$CellContext`newy; $CellContext`cy44 = \
-$CellContext`newx; $CellContext`cx4 = 0; $CellContext`cy4 = 
         0; $CellContext`cx44 = -$CellContext`newy; $CellContext`cy44 = \
-$CellContext`newx; $CellContext`ix1 = 
         2 ($CellContext`thickness1$$^3 ($CellContext`length1$$/
              12) + ($CellContext`length1$$ $CellContext`thickness1$$) \
($CellContext`width1$$/2 - $CellContext`thickness1$$/
               2)^2) + ($CellContext`thickness1$$ ($CellContext`width1$$ - 
              2 $CellContext`thickness1$$)^3)/12; $CellContext`iy1 = 
         2 (($CellContext`thickness1$$ $CellContext`length1$$^3)/
            12) + (($CellContext`width1$$ - 
             2 $CellContext`thickness1$$) $CellContext`thickness1$$^3)/
           12; $CellContext`ix11 = $CellContext`ix1 + ((
              2 $CellContext`thickness1$$) $CellContext`length1$$ + \
$CellContext`thickness1$$ ($CellContext`width1$$ - 
              2 $CellContext`thickness1$$)) $CellContext`newx^2; \
$CellContext`iy11 = $CellContext`iy1 + ((
              2 $CellContext`thickness1$$) $CellContext`length1$$ + \
$CellContext`thickness1$$ ($CellContext`width1$$ - 
              2 $CellContext`thickness1$$)) $CellContext`newy^2; \
$CellContext`ix2 = $CellContext`thickness2$$^3 ($CellContext`length2$$/
            12) + ($CellContext`thickness2$$^3 $CellContext`length2$$) \
($CellContext`width2$$/2 - $CellContext`thickness2$$/
             2 - $CellContext`cy2)^2 + ($CellContext`width2$$ - \
$CellContext`thickness2$$)^3 ($CellContext`thickness2$$/
            12) + (($CellContext`width2$$ - $CellContext`thickness2$$) \
$CellContext`thickness2$$) (($CellContext`width2$$ - \
$CellContext`thickness2$$)/2 - ($CellContext`width2$$/
              2 - $CellContext`thickness2$$ - $CellContext`cy2))^2; \
$CellContext`iy2 = ($CellContext`thickness2$$ $CellContext`length2$$^3)/12 + 
          2 (((($CellContext`width2$$ - $CellContext`thickness2$$)/
               2) $CellContext`thickness2$$^3)/
             12 + ($CellContext`thickness2$$ (($CellContext`width2$$ - \
$CellContext`thickness2$$)/
               2)) ($CellContext`length2$$/2 - $CellContext`thickness2$$/
               2)^2); $CellContext`ix22 = $CellContext`ix2 + \
($CellContext`length2$$ $CellContext`thickness2$$ + (
              2 $CellContext`thickness2$$) (($CellContext`width2$$ - \
$CellContext`thickness2$$)/
              2)) $CellContext`newx^2; $CellContext`iy22 = $CellContext`iy2 + \
($CellContext`length2$$ $CellContext`thickness2$$ + (
              2 $CellContext`thickness2$$) (($CellContext`width2$$ - \
$CellContext`thickness2$$)/
              2)) $CellContext`newy^2; $CellContext`ix3 = \
($CellContext`length3$$ $CellContext`width3$$^3)/
           12 - (($CellContext`length3$$ - 
            2 $CellContext`thickness3$$) ($CellContext`width3$$ - 
             2 $CellContext`thickness3$$)^3)/
          12; $CellContext`iy3 = ($CellContext`width3$$ \
$CellContext`length3$$^3)/
           12 - (($CellContext`width3$$ - 
            2 $CellContext`thickness3$$) ($CellContext`length3$$ - 
             2 $CellContext`thickness3$$)^3)/
          12; $CellContext`ix33 = $CellContext`ix3 + ($CellContext`length3$$ \
$CellContext`width3$$ - ($CellContext`length3$$ - 
             2 $CellContext`thickness3$$) ($CellContext`width3$$ - 
             2 $CellContext`thickness3$$)) $CellContext`newx^2; \
$CellContext`iy33 = $CellContext`iy3 + ($CellContext`length3$$ \
$CellContext`width3$$ - ($CellContext`length3$$ - 
             2 $CellContext`thickness3$$) ($CellContext`width3$$ - 
             2 $CellContext`thickness3$$)) $CellContext`newy^2; \
$CellContext`ix4 = 
         Pi ($CellContext`length4$$^4/4) - 
          Pi ($CellContext`thickness4$$^4/
           4); $CellContext`iy4 = $CellContext`ix4; $CellContext`ix44 = \
$CellContext`ix4 + (Pi $CellContext`length4$$^2 - 
            Pi $CellContext`thickness4$$^2) $CellContext`newx^2; \
$CellContext`iy44 = $CellContext`iy4 + (Pi $CellContext`length4$$^2 - 
            Pi $CellContext`thickness4$$^2) $CellContext`newy^2; 
        If[$CellContext`sectiontype$$ == 1, $CellContext`temp1 = 
          Row[{"\!\(\*OverscriptBox[\(x\), \(_\)]\)=", 
             NumberForm[$CellContext`cx1, {4, 3}], 
             Spacer[2], "m", 
             Spacer[15], "\!\(\*OverscriptBox[\(y\), \(_\)]\)=", 
             NumberForm[$CellContext`cy1, {4, 3}], 
             Spacer[2], "m"}]]; 
        If[$CellContext`sectiontype$$ == 2, $CellContext`temp1 = 
          Row[{"\!\(\*OverscriptBox[\(x\), \(_\)]\)=", 
             NumberForm[$CellContext`cx2, {4, 3}], 
             Spacer[2], "m", 
             Spacer[15], "\!\(\*OverscriptBox[\(y\), \(_\)]\)=", 
             NumberForm[$CellContext`cy2, {4, 3}], 
             Spacer[2], "m"}]]; 
        If[$CellContext`sectiontype$$ == 3, $CellContext`temp1 = 
          Row[{"\!\(\*OverscriptBox[\(x\), \(_\)]\)=", 
             NumberForm[$CellContext`cx3, {4, 3}], 
             Spacer[2], "m", 
             Spacer[15], "\!\(\*OverscriptBox[\(y\), \(_\)]\)=", 
             NumberForm[$CellContext`cy3, {4, 3}], 
             Spacer[2], "m"}]]; 
        If[$CellContext`sectiontype$$ == 4, $CellContext`temp1 = 
          Row[{"\!\(\*OverscriptBox[\(x\), \(_\)]\)=", 
             NumberForm[$CellContext`cx4, {4, 3}], 
             Spacer[2], "m", 
             Spacer[15], "\!\(\*OverscriptBox[\(y\), \(_\)]\)=", 
             NumberForm[$CellContext`cy4, {4, 3}], 
             Spacer[2], "m"}]]; 
        If[$CellContext`sectiontype$$ == 1, $CellContext`temp2 = 
          Row[{"I=\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", 
             NumberForm[$CellContext`ix1, {4, 3}], 
             Spacer[2], "\!\(\*SuperscriptBox[\(m\), \(4\)]\)"}]]; 
        If[$CellContext`sectiontype$$ == 2, $CellContext`temp2 = 
          Row[{"I=\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", 
             NumberForm[$CellContext`ix2, {4, 3}], 
             Spacer[2], "\!\(\*SuperscriptBox[\(m\), \(4\)]\)"}]]; 
        If[$CellContext`sectiontype$$ == 3, $CellContext`temp2 = 
          Row[{"I=\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", 
             NumberForm[$CellContext`ix3, {4, 3}], 
             Spacer[2], "\!\(\*SuperscriptBox[\(m\), \(4\)]\)"}]]; 
        If[$CellContext`sectiontype$$ == 4, $CellContext`temp2 = 
          Row[{"I=\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", 
             NumberForm[$CellContext`ix4, {4, 3}], 
             Spacer[2], "\!\(\*SuperscriptBox[\(m\), \(4\)]\)"}]]; 
        If[$CellContext`sectiontype$$ == 1, $CellContext`funcv = 
          Piecewise[{{((
                2 $CellContext`V$$) ($CellContext`width1$$/
                 2 - $CellContext`thickness1$$/
                2)) ($CellContext`x/$CellContext`ix1), $CellContext`x <= \
$CellContext`length1$$/
               2}, {((2 $CellContext`V$$) ($CellContext`width1$$/
                 2 - $CellContext`thickness1$$/
                2)) (($CellContext`length1$$ - \
$CellContext`x)/$CellContext`ix1), $CellContext`x > (-$CellContext`length1$$)/
               2}}]]; If[$CellContext`sectiontype$$ == 1, $CellContext`funch = 
          
          Piecewise[{{($CellContext`V$$ $CellContext`y) \
(($CellContext`width1$$/2 - $CellContext`y/
                2)/$CellContext`ix1), $CellContext`y <= \
(-$CellContext`width1$$)/
                2 + $CellContext`thickness1$$ + $CellContext`width1$$/
                2}, {(($CellContext`V$$ $CellContext`thickness1$$) \
$CellContext`length1$$) ((($CellContext`width1$$/
                   2 - $CellContext`thickness1$$/
                  2)/$CellContext`ix1)/$CellContext`thickness1$$) + \
$CellContext`V$$ ((($CellContext`y - $CellContext`thickness1$$) \
($CellContext`y/2 - $CellContext`thickness1$$/
                  2 + $CellContext`width1$$/
                   2 - $CellContext`y))/$CellContext`ix1), 
              
              Inequality[(-$CellContext`width1$$)/
                2 + $CellContext`thickness1$$ + $CellContext`width1$$/2, 
               Less, $CellContext`y, 
               LessEqual, $CellContext`width1$$/
                2 - $CellContext`thickness1$$ + $CellContext`width1$$/
                2]}, {(($CellContext`V$$ $CellContext`thickness1$$) \
$CellContext`length1$$) ((($CellContext`width1$$/
                   2 - $CellContext`thickness1$$/
                  2)/$CellContext`ix1)/$CellContext`length1$$) + 
              0 - $CellContext`V$$ ((((($CellContext`thickness1$$ - \
$CellContext`width1$$ + $CellContext`y)/2 + $CellContext`width1$$/
                   2 - $CellContext`thickness1$$) ($CellContext`length1$$ \
($CellContext`thickness1$$ - $CellContext`width1$$ + \
$CellContext`y)))/$CellContext`ix1)/$CellContext`length1$$), $CellContext`y > \
$CellContext`width1$$/2 - $CellContext`thickness1$$ + $CellContext`width1$$/
                2}}]]; If[$CellContext`sectiontype$$ == 2, $CellContext`funcv = 
          Piecewise[{{($CellContext`V$$ ($CellContext`width2$$/
                 2 - $CellContext`thickness2$$/
                2)) ($CellContext`x/$CellContext`ix2), $CellContext`x <= \
$CellContext`length2$$/
               2}, {($CellContext`V$$ ($CellContext`width2$$/
                 2 - $CellContext`thickness2$$/
                2)) (($CellContext`length2$$ - \
$CellContext`x)/$CellContext`ix2), $CellContext`x > -0.5}}]]; 
        If[$CellContext`sectiontype$$ == 2, $CellContext`funch = 
          Piecewise[{{$CellContext`V$$ (($CellContext`y \
($CellContext`width2$$/2 - $CellContext`y + $CellContext`y/
                  2 + $CellContext`cy2))/$CellContext`ix2), $CellContext`y <= \
$CellContext`width2$$/
               2}, {$CellContext`V$$ (($CellContext`y ($CellContext`width2$$/
                  2 - $CellContext`y/
                 2 + $CellContext`cy2))/$CellContext`ix2), \
$CellContext`width2$$/
               2 < $CellContext`y < $CellContext`width2$$ - \
$CellContext`thickness2$$}, {$CellContext`V$$ ((((($CellContext`width2$$/
                    2 + $CellContext`cy2) $CellContext`thickness2$$) \
(($CellContext`width2$$/2 + $CellContext`cy2)/
                    2) - (($CellContext`width2$$/
                    2 - $CellContext`thickness2$$ - $CellContext`cy2) \
$CellContext`thickness2$$) (($CellContext`width2$$/
                    2 - $CellContext`thickness2$$ - $CellContext`cy2)/
                   2))/$CellContext`ix2)/$CellContext`length2$$) - \
$CellContext`V$$ ((($CellContext`y - $CellContext`width2$$ + \
$CellContext`thickness2$$) (($CellContext`y - $CellContext`width2$$ + \
$CellContext`thickness2$$)/2 + $CellContext`width2$$/
                  2 - $CellContext`thickness2$$ - \
$CellContext`cy2))/$CellContext`ix2), $CellContext`width2$$ - \
$CellContext`thickness2$$ <= $CellContext`y}}]]; 
        If[$CellContext`sectiontype$$ == 3, $CellContext`funcv = 
          Piecewise[{{((
                2 $CellContext`V$$) ($CellContext`width3$$/
                 2 - $CellContext`thickness3$$/
                2)) ($CellContext`x/$CellContext`ix3), $CellContext`x <= \
$CellContext`length3$$/
               2}, {((2 $CellContext`V$$) ($CellContext`width3$$/
                 2 - $CellContext`thickness3$$/
                2)) (($CellContext`length3$$ - \
$CellContext`x)/$CellContext`ix3), $CellContext`x > (-$CellContext`length3$$)/
               2}}]]; If[$CellContext`sectiontype$$ == 3, $CellContext`funch = 
          Piecewise[{{($CellContext`V$$ $CellContext`y) \
(($CellContext`width3$$/2 - $CellContext`y/
                2)/$CellContext`ix3), $CellContext`y <= \
(-$CellContext`width3$$)/
                2 + $CellContext`thickness3$$ + $CellContext`width3$$/
                2}, {(((
                  2 $CellContext`V$$) $CellContext`thickness3$$) \
$CellContext`length3$$) ((($CellContext`width3$$/
                   2 - $CellContext`thickness3$$/
                  2)/$CellContext`ix3)/$CellContext`thickness3$$) + (
                2 $CellContext`V$$) ((($CellContext`y - \
$CellContext`thickness3$$) ($CellContext`y/2 - $CellContext`thickness3$$/
                  2 + $CellContext`width3$$/
                   2 - $CellContext`y))/$CellContext`ix3), 
              
              Inequality[(-$CellContext`width3$$)/
                2 + $CellContext`thickness3$$ + $CellContext`width3$$/2, 
               Less, $CellContext`y, 
               LessEqual, $CellContext`width3$$/
                2 - $CellContext`thickness3$$ + $CellContext`width3$$/
                2]}, {(($CellContext`V$$ $CellContext`thickness3$$) \
$CellContext`length3$$) ((($CellContext`width3$$/
                   2 - $CellContext`thickness3$$/
                  2)/$CellContext`ix3)/$CellContext`length3$$) + 
              0 - $CellContext`V$$ ((((($CellContext`thickness3$$ - \
$CellContext`width3$$ + $CellContext`y)/2 + $CellContext`width3$$/
                   2 - $CellContext`thickness3$$) ($CellContext`length3$$ \
($CellContext`thickness3$$ - $CellContext`width3$$ + \
$CellContext`y)))/$CellContext`ix3)/$CellContext`length3$$), $CellContext`y > \
$CellContext`width3$$/2 - $CellContext`thickness3$$ + $CellContext`width3$$/
                2}}]]; $CellContext`thetav1 = (Pi/2 - 
           ArcSin[($CellContext`length4$$ - \
$CellContext`x)/$CellContext`length4$$]) 
          2; $CellContext`areav1 = (
            Pi $CellContext`length4$$^2) ($CellContext`thetav1/(2 Pi)) - (
           Sin[$CellContext`thetav1/
             2] $CellContext`length4$$) ($CellContext`length4$$ - \
$CellContext`x); $CellContext`cv1 = (4 $CellContext`length4$$) (
           Sin[$CellContext`thetav1/2]^3/(
           3 ($CellContext`thetav1 - 
            Sin[$CellContext`thetav1]))); $CellContext`thetav2 = (Pi/2 - 
           ArcSin[($CellContext`length4$$ - \
$CellContext`x)/$CellContext`thickness4$$]) 
          2; $CellContext`areav2 = (
            Pi $CellContext`thickness4$$^2) ($CellContext`thetav2/(2 Pi)) - (
           Sin[$CellContext`thetav2/
             2] $CellContext`thickness4$$) ($CellContext`thickness4$$ - \
$CellContext`x); $CellContext`cv2 = (4 $CellContext`thickness4$$) (
           Sin[$CellContext`thetav2/2]^3/(
           3 ($CellContext`thetav2 - 
            
            Sin[$CellContext`thetav2]))); $CellContext`cv2all = \
($CellContext`areav1 $CellContext`cv1 - $CellContext`areav2 \
$CellContext`cv2)/($CellContext`areav1 - $CellContext`areav2); \
$CellContext`thetav3 = (Pi/2 - 
           ArcSin[($CellContext`length4$$ - ($CellContext`length4$$ 
              2 - $CellContext`x))/$CellContext`length4$$]) 
          2; $CellContext`areav3 = (
            Pi $CellContext`length4$$^2) ($CellContext`thetav3/(2 Pi)) - (
           Sin[$CellContext`thetav3/
             2] $CellContext`length4$$) ($CellContext`length4$$ - \
($CellContext`length4$$ 2 - $CellContext`x)); $CellContext`cv3 = (
           4 $CellContext`length4$$) (Sin[$CellContext`thetav3/2]^3/(
           3 ($CellContext`thetav3 - 
            Sin[$CellContext`thetav3]))); $CellContext`thetav4 = (Pi/2 - 
           ArcSin[($CellContext`length4$$ - ($CellContext`length4$$ 
              2 - $CellContext`x))/$CellContext`thickness4$$]) 
          2; $CellContext`areav4 = (
            Pi $CellContext`thickness4$$^2) ($CellContext`thetav4/(2 Pi)) - (
           Sin[$CellContext`thetav4/
             2] $CellContext`thickness4$$) ($CellContext`thickness4$$ - \
($CellContext`length4$$ 2 - $CellContext`x)); $CellContext`cv4 = (
           4 $CellContext`thickness4$$) (Sin[$CellContext`thetav4/2]^3/(
           3 ($CellContext`thetav4 - 
            Sin[$CellContext`thetav4]))); $CellContext`cv4all = \
($CellContext`areav3 $CellContext`cv3 - $CellContext`areav4 \
$CellContext`cv4)/($CellContext`areav3 - $CellContext`areav4); 
        If[$CellContext`sectiontype$$ == 4, $CellContext`funcv = 
          Piecewise[{{$CellContext`V$$ ((($CellContext`cv1 \
$CellContext`areav1)/((Sin[$CellContext`thetav1/2] $CellContext`length4$$) 
                2))/$CellContext`ix4), $CellContext`x <= \
$CellContext`length4$$ - $CellContext`thickness4$$}, {$CellContext`V$$ \
((($CellContext`cv2all ($CellContext`areav1 - $CellContext`areav2))/((
                  Sin[$CellContext`thetav1/2] $CellContext`length4$$) 2 - (
                 Sin[$CellContext`thetav2/2] $CellContext`thickness4$$) 
                2))/$CellContext`ix4), 
              
              Inequality[$CellContext`length4$$ - $CellContext`thickness4$$, 
               Less, $CellContext`x, 
               LessEqual, $CellContext`length4$$]}, {$CellContext`V$$ \
((($CellContext`cv4all ($CellContext`areav3 - $CellContext`areav4))/((
                  Sin[$CellContext`thetav3/2] $CellContext`length4$$) 2 - (
                 Sin[$CellContext`thetav4/2] $CellContext`thickness4$$) 
                2))/$CellContext`ix4), 
              
              Inequality[$CellContext`length4$$, Less, $CellContext`x, 
               LessEqual, $CellContext`length4$$ + \
$CellContext`thickness4$$]}, {$CellContext`V$$ ((($CellContext`cv3 \
$CellContext`areav3)/((Sin[$CellContext`thetav3/2] $CellContext`length4$$) 
                2))/$CellContext`ix4), $CellContext`length4$$ + \
$CellContext`thickness4$$ < $CellContext`x}}]]; $CellContext`thetah1 = (Pi/2 - 
           ArcSin[($CellContext`length4$$ - \
$CellContext`y)/$CellContext`length4$$]) 
          2; $CellContext`areah1 = (
            Pi $CellContext`length4$$^2) ($CellContext`thetah1/(2 Pi)) - (
           Sin[$CellContext`thetah1/
             2] $CellContext`length4$$) ($CellContext`length4$$ - \
$CellContext`y); $CellContext`ch1 = (4 $CellContext`length4$$) (
           Sin[$CellContext`thetah1/2]^3/(
           3 ($CellContext`thetah1 - 
            Sin[$CellContext`thetah1]))); $CellContext`thetah2 = (Pi/2 - 
           ArcSin[($CellContext`length4$$ - \
$CellContext`y)/$CellContext`thickness4$$]) 
          2; $CellContext`areah2 = (
            Pi $CellContext`thickness4$$^2) ($CellContext`thetah2/(2 Pi)) - (
           Sin[$CellContext`thetah2/
             2] $CellContext`thickness4$$) ($CellContext`thickness4$$ - \
$CellContext`y); $CellContext`ch2 = (4 $CellContext`thickness4$$) (
           Sin[$CellContext`thetah2/2]^3/(
           3 ($CellContext`thetah2 - 
            Sin[$CellContext`thetah2]))); $CellContext`ch2all = \
($CellContext`areah1 $CellContext`ch1 - $CellContext`areah2 \
$CellContext`ch2)/($CellContext`areah1 - $CellContext`areah2); \
$CellContext`thetah3 = (Pi/2 - 
           ArcSin[($CellContext`length4$$ - ($CellContext`length4$$ 
              2 - $CellContext`y))/$CellContext`length4$$]) 
          2; $CellContext`areah3 = (
            Pi $CellContext`length4$$^2) ($CellContext`thetah3/(2 Pi)) - (
           Sin[$CellContext`thetah3/
             2] $CellContext`length4$$) ($CellContext`length4$$ - \
($CellContext`length4$$ 2 - $CellContext`y)); $CellContext`ch3 = (
           4 $CellContext`length4$$) (Sin[$CellContext`thetah3/2]^3/(
           3 ($CellContext`thetah3 - 
            Sin[$CellContext`thetah3]))); $CellContext`thetah4 = (Pi/2 - 
           ArcSin[($CellContext`length4$$ - ($CellContext`length4$$ 
              2 - $CellContext`y))/$CellContext`thickness4$$]) 
          2; $CellContext`areah4 = (
            Pi $CellContext`thickness4$$^2) ($CellContext`thetah4/(2 Pi)) - (
           Sin[$CellContext`thetah4/
             2] $CellContext`thickness4$$) ($CellContext`thickness4$$ - \
($CellContext`length4$$ 2 - $CellContext`y)); $CellContext`ch4 = (
           4 $CellContext`thickness4$$) (Sin[$CellContext`thetah4/2]^3/(
           3 ($CellContext`thetah4 - 
            Sin[$CellContext`thetah4]))); $CellContext`ch4all = \
($CellContext`areah3 $CellContext`ch3 - $CellContext`areah4 \
$CellContext`ch4)/($CellContext`areah3 - $CellContext`areah4); 
        If[$CellContext`sectiontype$$ == 4, $CellContext`funch = 
          Piecewise[{{$CellContext`V$$ ((($CellContext`ch1 \
$CellContext`areah1)/((Sin[$CellContext`thetah1/2] $CellContext`length4$$) 
                2))/$CellContext`ix4), $CellContext`y <= \
$CellContext`length4$$ - $CellContext`thickness4$$}, {$CellContext`V$$ \
((($CellContext`ch2all ($CellContext`areah1 - $CellContext`areah2))/((
                  Sin[$CellContext`thetah1/2] $CellContext`length4$$) 2 - (
                 Sin[$CellContext`thetah2/2] $CellContext`thickness4$$) 
                2))/$CellContext`ix4), 
              
              Inequality[$CellContext`length4$$ - $CellContext`thickness4$$, 
               Less, $CellContext`y, 
               LessEqual, $CellContext`length4$$]}, {$CellContext`V$$ \
((($CellContext`ch4all ($CellContext`areah3 - $CellContext`areah4))/((
                  Sin[$CellContext`thetah3/2] $CellContext`length4$$) 2 - (
                 Sin[$CellContext`thetah4/2] $CellContext`thickness4$$) 
                2))/$CellContext`ix4), 
              
              Inequality[$CellContext`length4$$, Less, $CellContext`y, 
               LessEqual, $CellContext`length4$$ + \
$CellContext`thickness4$$]}, {$CellContext`V$$ ((($CellContext`ch3 \
$CellContext`areah3)/((Sin[$CellContext`thetah3/2] $CellContext`length4$$) 
                2))/$CellContext`ix4), $CellContext`length4$$ + \
$CellContext`thickness4$$ < $CellContext`y}}]]; 
        If[$CellContext`sectiontype$$ == 
          1, $CellContext`limitv = $CellContext`posv$$ + \
$CellContext`length1$$/2 + 0.001]; 
        If[$CellContext`sectiontype$$ == 
          1, $CellContext`limith = $CellContext`posh$$ + \
$CellContext`width1$$/2 + 0.001]; 
        If[$CellContext`sectiontype$$ == 
          2, $CellContext`limitv = $CellContext`posv$$ + \
$CellContext`length2$$/2 + 0.001]; 
        If[$CellContext`sectiontype$$ == 
          2, $CellContext`limith = $CellContext`posh$$ + \
$CellContext`width2$$/2 + 0.001]; 
        If[$CellContext`sectiontype$$ == 
          3, $CellContext`limitv = $CellContext`posv$$ + \
$CellContext`length3$$/2 + 0.001]; 
        If[$CellContext`sectiontype$$ == 
          3, $CellContext`limith = $CellContext`posh$$ + \
$CellContext`width3$$/2 + 0.001]; 
        If[$CellContext`sectiontype$$ == 
          4, $CellContext`limitv = $CellContext`posv$$ + \
$CellContext`length4$$ + 0.001]; 
        If[$CellContext`sectiontype$$ == 
          4, $CellContext`limith = $CellContext`posh$$ + \
$CellContext`length4$$ + 0.001]; 
        If[$CellContext`orientation$$ == Vertical, $CellContext`shear = 
          Labeled[
            
            Plot[$CellContext`funcv, {$CellContext`x, 0, $CellContext`limitv},
              Frame -> True, 
             FrameLabel -> {
              "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)", 
               "\!\(\*\nStyleBox[\"Shear\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., \
0., 0.]]\)\!\(\*\nStyleBox[\"Stress\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"kN\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"/\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m2\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)"}, PlotRange -> {{0, 1}, {0, 150}}, 
             ImageMargins -> 5, ImageSize -> 275, AspectRatio -> 0.35, 
             FrameTicksStyle -> Directive[10], AxesOrigin -> {0, 0}, Filling -> 
             Axis, FillingStyle -> Lighter[Green, 0.8]], 
            Text[
             Style["Shear Stress", Bold, 11]], {{Top, Center}}, 
            Spacings -> {Automatic, -0.35}]]; 
        If[$CellContext`orientation$$ == Horizontal, $CellContext`shear = 
          Labeled[
            
            Plot[$CellContext`funch, {$CellContext`y, 0, $CellContext`limith},
              Frame -> True, 
             FrameLabel -> {
              "\!\(\*\nStyleBox[\"y\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)", 
               "\!\(\*\nStyleBox[\"Shear\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., \
0., 0.]]\)\!\(\*\nStyleBox[\"Stress\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"kN\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"/\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m2\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)"}, PlotRange -> {{0, 1}, {0, 150}}, 
             ImageMargins -> 5, ImageSize -> 275, AspectRatio -> 0.35, 
             FrameTicksStyle -> Directive[10], AxesOrigin -> {0, 0}, Filling -> 
             Axis, FillingStyle -> Lighter[Green, 0.8]], 
            Text[
             Style["Shear Stress", Bold, 11]], {{Top, Center}}, 
            Spacings -> {Automatic, -0.35}]]; 
        If[$CellContext`sectiontype$$ == 
          2, $CellContext`xx = $CellContext`cx2, $CellContext`xx = 0]; 
        If[$CellContext`sectiontype$$ == 
          2, $CellContext`yy = $CellContext`cy2, $CellContext`yy = 0]; Column[{
           Item[$CellContext`dwf0$ = {
               Opacity[$CellContext`opa0$$], 
               Dashing[{0.01}], Blue, 
               Thickness[0.002], 
               Arrowheads[0.02], 
               
               Arrow[{{
                 1 $CellContext`size$, $CellContext`yy}, \
{-$CellContext`size$, $CellContext`yy}}], 
               
               Arrow[{{$CellContext`xx, -$CellContext`size$}, \
{$CellContext`xx, 1 $CellContext`size$}}], 
               Text[
               "\!\(\*\nStyleBox[\"z\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {-$CellContext`size$, (-0.05) $CellContext`size$}], 
               Text[
               "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`size$, 
                 1 $CellContext`size$}], 
               Text[
               "\!\(\*\nStyleBox[\"o\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {0, 0} + {-0.05, -0.05}]}; $CellContext`dwf1$ = {
               Opacity[$CellContext`opa1$ 0.75], 
               Lighter[Blue], 
               
               Rectangle[{(-$CellContext`thickness1$$)/
                 2, (-$CellContext`width1$$)/
                  2 + $CellContext`thickness1$$}, {$CellContext`thickness1$$/
                 2, $CellContext`width1$$/2 - $CellContext`thickness1$$}], 
               
               Rectangle[{(-$CellContext`length1$$)/
                 2, $CellContext`width1$$/
                  2 - $CellContext`thickness1$$}, {$CellContext`length1$$/
                 2, $CellContext`width1$$/2}], 
               
               Rectangle[{(-$CellContext`length1$$)/
                 2, (-$CellContext`width1$$)/2}, {$CellContext`length1$$/
                 2, (-$CellContext`width1$$)/2 + $CellContext`thickness1$$}], 
               Black, 
               
               Arrow[{{$CellContext`cx1, $CellContext`cy1}, \
{$CellContext`cx1, (-$CellContext`length1$$)/4 - $CellContext`V$$/50}}], 
               Text[
                Style[
                "V", FontSize -> 
                 15], {$CellContext`cx1, (-$CellContext`length1$$)/
                  4 - $CellContext`V$$/50 - 0.05}], Black, 
               
               Arrow[{{(-$CellContext`length1$$)/2 - $CellContext`length1$$/
                  10, (-$CellContext`width1$$)/
                  2}, {(-$CellContext`length1$$)/2 - $CellContext`length1$$/
                  10, $CellContext`width1$$/2}}], 
               
               Arrow[{{(-$CellContext`length1$$)/2 - $CellContext`length1$$/
                  10, $CellContext`width1$$/
                  2}, {(-$CellContext`length1$$)/2 - $CellContext`length1$$/
                  10, (-$CellContext`width1$$)/2}}], 
               
               Text[$CellContext`width1$$, {(-$CellContext`length1$$)/2 - 
                 0.25, 0}], 
               
               Arrow[{{(-$CellContext`length1$$)/
                  2, $CellContext`width1$$/2 + $CellContext`width1$$/
                   10}, {$CellContext`length1$$/
                  2, $CellContext`width1$$/2 + $CellContext`width1$$/10}}], 
               
               Arrow[{{$CellContext`length1$$/
                  2, $CellContext`width1$$/2 + $CellContext`width1$$/
                   10}, {(-$CellContext`length1$$)/
                  2, $CellContext`width1$$/2 + $CellContext`width1$$/10}}], 
               
               Text[$CellContext`length1$$, {
                0, $CellContext`width1$$/2 + $CellContext`width1$$/5}], 
               
               Arrow[{{$CellContext`length1$$/4, (-$CellContext`width1$$)/2 - 
                  0.1}, {$CellContext`length1$$/4, (-$CellContext`width1$$)/
                  2}}], 
               
               Arrow[{{$CellContext`length1$$/
                  4, (-$CellContext`width1$$)/2 + $CellContext`thickness1$$ + 
                  0.1}, {$CellContext`length1$$/
                  4, (-$CellContext`width1$$)/
                   2 + $CellContext`thickness1$$}}], 
               
               Text[$CellContext`thickness1$$, {$CellContext`length1$$/4 + 
                 0.125, (-$CellContext`width1$$)/
                  2 + $CellContext`thickness1$$ + 0.1}], 
               Thickness[0.01], Red, 
               Opacity[$CellContext`opa1l $CellContext`opa1$], 
               
               Line[{{$CellContext`posv$$, -0.9}, {$CellContext`posv$$, 
                  0.9}}], 
               Text[
                Style["A", FontSize -> 15], {$CellContext`posv$$, 1.}], 
               Text[
                Style["A", FontSize -> 15], {$CellContext`posv$$, -1.}], 
               Opacity[(1 - $CellContext`opa1l) $CellContext`opa1$], 
               
               Line[{{-0.9, $CellContext`posh$$}, {
                 0.9, $CellContext`posh$$}}], 
               Text[
                Style["A", FontSize -> 15], {1., $CellContext`posh$$}], 
               Text[
                Style["A", FontSize -> 15], {-1., $CellContext`posh$$}], 
               Thickness[0.002], Black, 
               Opacity[$CellContext`poc$$ $CellContext`opa1$], Red, 
               PointSize[0.02], 
               Point[{$CellContext`cx1, $CellContext`cy1}], 
               Thickness[0.002], Dashed, 
               Opacity[$CellContext`opa1$ 0.75], Black, 
               
               Line[{{(-$CellContext`length1$$)/2 - $CellContext`length1$$/
                  5, $CellContext`width1$$/2}, {(-$CellContext`length1$$)/
                  2, $CellContext`width1$$/2}}], 
               
               Line[{{(-$CellContext`length1$$)/2 - $CellContext`length1$$/
                  5, (-$CellContext`width1$$)/2}, {(-$CellContext`length1$$)/
                  2, (-$CellContext`width1$$)/2}}], 
               
               Line[{{(-$CellContext`length1$$)/2, $CellContext`width1$$/
                  2}, {(-$CellContext`length1$$)/
                  2, $CellContext`width1$$/2 + $CellContext`width1$$/5}}], 
               
               Line[{{$CellContext`length1$$/2, $CellContext`width1$$/
                  2}, {$CellContext`length1$$/
                  2, $CellContext`width1$$/2 + $CellContext`width1$$/
                   5}}]}; $CellContext`dwf2$ = {
               Opacity[$CellContext`opa2$ 0.75], 
               Lighter[Blue], 
               
               Rectangle[{(-$CellContext`length2$$)/
                 2, $CellContext`width2$$/
                  2 - $CellContext`thickness2$$}, {$CellContext`length2$$/
                 2, $CellContext`width2$$/2}], 
               
               Rectangle[{(-$CellContext`thickness2$$)/
                 2, (-$CellContext`width2$$)/2}, {$CellContext`thickness2$$/
                 2, $CellContext`width2$$/2 - $CellContext`thickness2$$}], 
               Black, 
               
               Arrow[{{$CellContext`cx2, $CellContext`cy2}, \
{$CellContext`cx2, (-$CellContext`length2$$)/4 - $CellContext`V$$/50}}], 
               Text[
                Style[
                "V", FontSize -> 
                 15], {$CellContext`cx2, (-$CellContext`length2$$)/
                  4 - $CellContext`V$$/50 - 0.05}], 
               
               Arrow[{{(-$CellContext`length2$$)/2 - $CellContext`length2$$/
                  10, (-$CellContext`width2$$)/
                  2}, {(-$CellContext`length2$$)/2 - $CellContext`length2$$/
                  10, $CellContext`width2$$/2}}], 
               
               Arrow[{{(-$CellContext`length2$$)/2 - $CellContext`length2$$/
                  10, $CellContext`width2$$/
                  2}, {(-$CellContext`length2$$)/2 - $CellContext`length2$$/
                  10, (-$CellContext`width2$$)/2}}], 
               
               Text[$CellContext`width2$$, {(-$CellContext`length2$$)/2 - 
                 0.25, 0}], 
               
               Arrow[{{(-$CellContext`length2$$)/
                  2, $CellContext`width2$$/2 + $CellContext`width2$$/
                   10}, {$CellContext`length2$$/
                  2, $CellContext`width2$$/2 + $CellContext`width2$$/10}}], 
               
               Arrow[{{$CellContext`length2$$/
                  2, $CellContext`width2$$/2 + $CellContext`width2$$/
                   10}, {(-$CellContext`length2$$)/
                  2, $CellContext`width2$$/2 + $CellContext`width2$$/10}}], 
               
               Text[$CellContext`length2$$, {
                0, $CellContext`width2$$/2 + $CellContext`width2$$/5}], 
               
               Arrow[{{(-$CellContext`thickness2$$)/2 - 
                  0.1, $CellContext`width2$$/2 - $CellContext`thickness2$$ 
                  2}, {(-$CellContext`thickness2$$)/
                  2, $CellContext`width2$$/2 - $CellContext`thickness2$$ 2}}], 
               
               Arrow[{{$CellContext`thickness2$$/2 + 
                  0.1, $CellContext`width2$$/2 - $CellContext`thickness2$$ 
                  2}, {$CellContext`thickness2$$/
                  2, $CellContext`width2$$/2 - $CellContext`thickness2$$ 2}}], 
               
               Text[$CellContext`thickness2$$, {$CellContext`thickness2$$ + 
                 0.2, $CellContext`width2$$/2 - $CellContext`thickness2$$ 2}], 
               Thickness[0.01], Red, 
               Opacity[$CellContext`opa1l $CellContext`opa2$], 
               
               Line[{{$CellContext`posv$$, -0.9}, {$CellContext`posv$$, 
                  0.9}}], 
               Text[
                Style["A", FontSize -> 15], {$CellContext`posv$$, 1.}], 
               Text[
                Style["A", FontSize -> 15], {$CellContext`posv$$, -1.}], 
               Opacity[(1 - $CellContext`opa1l) $CellContext`opa2$], 
               
               Line[{{-0.9, $CellContext`posh$$}, {
                 0.9, $CellContext`posh$$}}], 
               Text[
                Style["A", FontSize -> 15], {1., $CellContext`posh$$}], 
               Text[
                Style["A", FontSize -> 15], {-1., $CellContext`posh$$}], 
               Opacity[$CellContext`opa2$ 0.75], Dashed, Black, 
               Thickness[0.002], 
               
               Line[{{(-$CellContext`length2$$)/2 - $CellContext`length2$$/
                  5, $CellContext`width2$$/2}, {(-$CellContext`length2$$)/
                  2, $CellContext`width2$$/2}}], 
               
               Line[{{(-$CellContext`length2$$)/2 - $CellContext`length2$$/
                  5, (-$CellContext`width2$$)/
                  2}, {$CellContext`length2$$/
                   2 - $CellContext`thickness2$$, (-$CellContext`width2$$)/
                  2}}], 
               
               Line[{{(-$CellContext`length2$$)/2, $CellContext`width2$$/
                  2}, {(-$CellContext`length2$$)/
                  2, $CellContext`width2$$/2 + $CellContext`width2$$/5}}], 
               
               Line[{{$CellContext`length2$$/2, $CellContext`thickness2$$/
                  2}, {$CellContext`length2$$/
                  2, $CellContext`width2$$/2 + $CellContext`width2$$/5}}], 
               Opacity[$CellContext`poc$$ $CellContext`opa2$], Red, 
               PointSize[0.02], 
               
               Point[{$CellContext`cx2, $CellContext`cy2}]}; \
$CellContext`dwf3$ = {
               Opacity[$CellContext`opa3$ 0.75], 
               Lighter[Blue], 
               
               Rectangle[{(-$CellContext`length3$$)/
                 2, (-$CellContext`width3$$)/2}, {$CellContext`length3$$/
                 2, $CellContext`width3$$/2}], 
               Opacity[$CellContext`opa3$], White, 
               
               Rectangle[{(-$CellContext`length3$$)/
                  2 + $CellContext`thickness3$$, (-$CellContext`width3$$)/
                  2 + $CellContext`thickness3$$}, {$CellContext`length3$$/
                  2 - $CellContext`thickness3$$, $CellContext`width3$$/
                  2 - $CellContext`thickness3$$}], Black, 
               
               Arrow[{{$CellContext`cx3, $CellContext`cy3}, \
{$CellContext`cx3, (-$CellContext`length3$$)/4 - $CellContext`V$$/50}}], 
               Text[
                Style[
                "V", FontSize -> 
                 15], {$CellContext`cx3, (-$CellContext`length3$$)/
                  4 - $CellContext`V$$/50 - 0.05}], 
               
               Arrow[{{(-$CellContext`length3$$)/2 - $CellContext`length3$$/
                  10, (-$CellContext`width3$$)/
                  2}, {(-$CellContext`length3$$)/2 - $CellContext`length3$$/
                  10, $CellContext`width3$$/2}}], 
               
               Arrow[{{(-$CellContext`length3$$)/2 - $CellContext`length3$$/
                  10, $CellContext`width3$$/
                  2}, {(-$CellContext`length3$$)/2 - $CellContext`length3$$/
                  10, (-$CellContext`width3$$)/2}}], 
               
               Text[$CellContext`width3$$, {(-$CellContext`length3$$)/2 - 
                 0.25, 0}], 
               
               Arrow[{{(-$CellContext`length3$$)/
                  2, $CellContext`width3$$/2 + $CellContext`width3$$/
                   10}, {$CellContext`length3$$/
                  2, $CellContext`width3$$/2 + $CellContext`width3$$/10}}], 
               
               Arrow[{{$CellContext`length3$$/
                  2, $CellContext`width3$$/2 + $CellContext`width3$$/
                   10}, {(-$CellContext`length3$$)/
                  2, $CellContext`width3$$/2 + $CellContext`width3$$/10}}], 
               
               Text[$CellContext`length3$$, {
                0, $CellContext`width3$$/2 + $CellContext`width3$$/5}], 
               
               Arrow[{{$CellContext`length3$$/6, (-$CellContext`width3$$)/2 - 
                  0.1}, {$CellContext`length3$$/6, (-$CellContext`width3$$)/
                  2}}], 
               
               Arrow[{{$CellContext`length3$$/
                  6, (-$CellContext`width3$$)/2 + $CellContext`thickness3$$ + 
                  0.1}, {$CellContext`length3$$/
                  6, (-$CellContext`width3$$)/
                   2 + $CellContext`thickness3$$}}], 
               
               Text[$CellContext`thickness3$$, {$CellContext`length3$$/
                 6, (-$CellContext`width3$$)/2 + $CellContext`thickness3$$ + 
                 0.125}], 
               Thickness[0.01], Red, 
               Opacity[$CellContext`opa1l $CellContext`opa3$], 
               
               Line[{{$CellContext`posv$$, -0.9}, {$CellContext`posv$$, 
                  0.9}}], 
               Text[
                Style["A", FontSize -> 15], {$CellContext`posv$$, 1.}], 
               Text[
                Style["A", FontSize -> 15], {$CellContext`posv$$, -1.}], 
               Opacity[(1 - $CellContext`opa1l) $CellContext`opa3$], 
               
               Line[{{-0.9, $CellContext`posh$$}, {
                 0.9, $CellContext`posh$$}}], 
               Text[
                Style["A", FontSize -> 15], {1., $CellContext`posh$$}], 
               Text[
                Style["A", FontSize -> 15], {-1., $CellContext`posh$$}], 
               Opacity[$CellContext`opa3$ 0.75], Black, 
               Thickness[0.002], Dashed, 
               
               Line[{{(-$CellContext`length3$$)/2 - $CellContext`length3$$/
                  5, $CellContext`width3$$/2}, {(-$CellContext`length3$$)/
                  2, $CellContext`width3$$/2}}], 
               
               Line[{{(-$CellContext`length3$$)/2 - $CellContext`length3$$/
                  5, (-$CellContext`width3$$)/2}, {(-$CellContext`length3$$)/
                  2, (-$CellContext`width3$$)/2}}], 
               
               Line[{{(-$CellContext`length3$$)/2, $CellContext`width3$$/
                  2}, {(-$CellContext`length3$$)/
                  2, $CellContext`width3$$/2 + $CellContext`width3$$/5}}], 
               
               Line[{{$CellContext`length3$$/2, $CellContext`width3$$/
                  2}, {$CellContext`length3$$/
                  2, $CellContext`width3$$/2 + $CellContext`width3$$/5}}], 
               Opacity[$CellContext`poc$$ $CellContext`opa3$], Red, 
               PointSize[0.02], 
               
               Point[{$CellContext`cx3, $CellContext`cy3}]}; \
$CellContext`dwf4$ = {
               Opacity[$CellContext`opa4$ 0.75], 
               Lighter[Blue], 
               Disk[{0, 0}, $CellContext`length4$$], 
               Opacity[$CellContext`opa4$], White, 
               Disk[{0, 0}, $CellContext`thickness4$$], Black, 
               
               Arrow[{{$CellContext`cx4, $CellContext`cy4}, \
{$CellContext`cx4, (-$CellContext`length4$$)/4 - $CellContext`V$$/50}}], 
               Text[
                Style[
                "V", FontSize -> 
                 15], {$CellContext`cx4, (-$CellContext`length4$$)/
                  4 - $CellContext`V$$/50 - 0.05}], 
               
               Arrow[{{0, 
                 0}, {(Sqrt[2]/2) $CellContext`thickness4$$, (Sqrt[2]/
                   2) $CellContext`thickness4$$}}], 
               
               Text[$CellContext`thickness4$$, {(Sqrt[2]/
                    2) $CellContext`thickness4$$ - 
                  0.1, (Sqrt[2]/2) $CellContext`thickness4$$ + 0.1}/2], 
               
               Arrow[{{0, 
                 0}, {((-Sqrt[2])/2) $CellContext`length4$$, (Sqrt[2]/
                   2) $CellContext`length4$$}}], 
               Text[$CellContext`length4$$, {((-Sqrt[2])/
                    2) $CellContext`length4$$ + 
                  0.1, (Sqrt[2]/2) $CellContext`length4$$ + 0.1}/2], 
               Thickness[0.01], Red, 
               Opacity[$CellContext`opa1l $CellContext`opa4$], 
               
               Line[{{$CellContext`posv$$, -0.9}, {$CellContext`posv$$, 
                  0.9}}], 
               Text[
                Style["A", FontSize -> 15], {$CellContext`posv$$, 1.}], 
               Text[
                Style["A", FontSize -> 15], {$CellContext`posv$$, -1.}], 
               Opacity[(1 - $CellContext`opa1l) $CellContext`opa4$], 
               
               Line[{{-0.9, $CellContext`posh$$}, {
                 0.9, $CellContext`posh$$}}], 
               Text[
                Style["A", FontSize -> 15], {1., $CellContext`posh$$}], 
               Text[
                Style["A", FontSize -> 15], {-1., $CellContext`posh$$}], 
               Opacity[$CellContext`poc$$ $CellContext`opa4$], Red, 
               PointSize[0.02], 
               
               Point[{$CellContext`cx4, $CellContext`cy4}]}; \
$CellContext`dwf9$ = {
               Opacity[1], Red, 
               
               Arrow[{{$CellContext`newy, $CellContext`newx}, \
{$CellContext`newy, $CellContext`newx} + {0, 0.5}}], 
               
               Arrow[{{$CellContext`newy, $CellContext`newx}, \
{$CellContext`newy, $CellContext`newx} + {0.5, 0}}], 
               Text[
               "\!\(\*\nStyleBox[\"o\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\"'\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {$CellContext`newy, $CellContext`newx} + {-0.05, 
                  0}], 
               Text[
               "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\"'\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {$CellContext`newy, $CellContext`newx} + {
                 0, 0.55}], 
               Text[
               "x'", {$CellContext`newy, $CellContext`newx} + {
                 0.55, 0}]}; $CellContext`dw1 = 
             
             Graphics[{$CellContext`dwf1$, $CellContext`dwf2$, \
$CellContext`dwf3$, $CellContext`dwf4$, $CellContext`dwf0$}, 
               PlotRange -> {{(-1.05) $CellContext`size$, 
                  1.05 $CellContext`size$}, {(-1.05) $CellContext`size$, 
                  1.05 $CellContext`size$}}, ImageSize -> 500, Frame -> True]; 
            Show[$CellContext`dw1]], 
           Item[
            Column[{
              Grid[{{
                 PaneSelector[{
                   Item[$CellContext`shear, ItemSize -> Full]}, 
                  Dynamic[$CellContext`opaf$$]]}}, Alignment -> Left, 
               Spacings -> {Automatic, 2.1}]}], ControlPlacement -> Right]}, 
          Center]], "Specifications" :> {{{$CellContext`opa0$$, 0, 
          Row[{"Coordinates visibility", 
            Spacer[30]}]}, {1 -> "On", 0 -> "off"}, ControlType -> 
         RadioButton, ControlPlacement -> 
         1}, {{$CellContext`sectiontype$$, 1, ""}, {
         1 -> "1", 2 -> "2", 3 -> "3", 4 -> "4"}, ControlType -> 
         RadioButtonBar, ControlPlacement -> 2}, {{$CellContext`length1$$, 1, 
          Row[{"Length [m]", 
            Spacer[63]}]}, 0.3, 1, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 3}, {{$CellContext`width1$$, 1, 
          Row[{"Height [m]", 
            Spacer[63]}]}, 0.3, 1, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 4}, {{$CellContext`length2$$, 1, 
          Row[{"Length [m]", 
            Spacer[63]}]}, 0.3, 1, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 5}, {{$CellContext`width2$$, 1, 
          Row[{"Height [m]", 
            Spacer[63]}]}, 0.3, 1, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 6}, {{$CellContext`length3$$, 1, 
          Row[{"Length [m]", 
            Spacer[63]}]}, 0.3, 1, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 7}, {{$CellContext`width3$$, 1, 
          Row[{"Height [m]", 
            Spacer[63]}]}, 0.3, 1, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 8}, {{$CellContext`length4$$, 0.5, 
          Row[{"Outer Radius [m]", 
            Spacer[30]}]}, 0.3, 0.5, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 9}, {{$CellContext`thickness1$$, 0.1, 
          Row[{"Thickness [m]", 
            Spacer[48]}]}, 0.05, 0.1, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 10}, {{$CellContext`thickness2$$, 0.1, 
          Row[{"Thickness [m]", 
            Spacer[48]}]}, 0.05, 0.1, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 11}, {{$CellContext`thickness3$$, 0.1, 
          Row[{"Thickness [m]", 
            Spacer[48]}]}, 0.05, 0.1, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 12}, {{$CellContext`thickness4$$, 0.2, 
          Row[{"Inner Radius [m]", 
            Spacer[34]}]}, 0.05, 0.2, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 13}, {{$CellContext`V$$, 3, 
          Row[{"Magnitude of shear force", 
            Spacer[25]}]}, 0.1, 8, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 
         14}, {{$CellContext`orientation$$, Vertical, 
          Text[
           Style[
           "\!\(\*\nStyleBox[\"Orientation\",\nFontWeight->\"Bold\"]\)", 
            12]]}, {Vertical, Horizontal}, ImageSize -> Tiny, ControlType -> 
         Setter, ControlPlacement -> 15}, {{$CellContext`opaf$$, 1, 
          
          Row[{"\!\(\*\nStyleBox[\"Shear\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"Force\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"Diagram\",\nFontWeight->\"Bold\"]\)", 
            Spacer[10]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         RadioButton, ControlPlacement -> 16}, {{$CellContext`posv$$, -0.9, 
          Row[{"Position of AA Plane", 
            Spacer[48]}]}, -1, 1, ImageSize -> Small, Appearance -> "Labeled",
          ControlPlacement -> 17}, {{$CellContext`posh$$, -0.9, 
          Row[{"Position of AA Plane", 
            Spacer[34]}]}, -1, 1, 0.01, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 18}, {{$CellContext`poc$$, 1, 
          
          Row[{"\!\(\*\nStyleBox[\"Position\",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"of\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"Centroid\",\nFontWeight->\"Bold\"]\)", 
            Spacer[10]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         RadioButton, ControlPlacement -> 19}, {{$CellContext`moi$$, 1, 
          
          Row[{"\!\(\*\nStyleBox[\"Moment\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"of\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"Inertia\",\nFontWeight->\"Bold\"]\)", 
            Spacer[19]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         RadioButton, ControlPlacement -> 20}, 
        Grid[{{
           Manipulate`Place[1]}, {
           Style[
           "\!\(\*\nStyleBox[\"Select\",\nFontFamily->\"Arial\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontFamily->\"Arial\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"section\",\nFontFamily->\"Arial\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontFamily->\"Arial\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"type\",\n\
FontFamily->\"Arial\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 10]}, {
           Dynamic[$CellContext`im1, SynchronousUpdating -> False]}, {
           Manipulate`Place[2]}, {
           PaneSelector[{1 -> Column[{
                Manipulate`Place[3], 
                Manipulate`Place[4]}], 2 -> Column[{
                Manipulate`Place[5], 
                Manipulate`Place[6]}], 3 -> Column[{
                Manipulate`Place[7], 
                Manipulate`Place[8]}], 4 -> Column[{
                Manipulate`Place[9]}]}, 
            Dynamic[$CellContext`sectiontype$$]]}, {
           PaneSelector[{1 -> Column[{
                Manipulate`Place[10]}], 2 -> Column[{
                Manipulate`Place[11]}], 3 -> Column[{
                Manipulate`Place[12]}], 4 -> Column[{
                Manipulate`Place[13]}]}, 
            Dynamic[$CellContext`sectiontype$$]]}, {
           Manipulate`Place[14]}, {
           Manipulate`Place[15]}, {
           Manipulate`Place[16]}, {
           PaneSelector[{Vertical -> Column[{
                Manipulate`Place[17]}], Horizontal -> Column[{
                Manipulate`Place[18]}]}, 
            Dynamic[$CellContext`orientation$$]]}, {
           Manipulate`Place[19]}, {
           Row[{
             Dynamic[
              If[$CellContext`poc$$ == 1, $CellContext`temp1, 
               Invisible[$CellContext`temp1]]]}]}, {
           Manipulate`Place[20]}, {
           Row[{
             Dynamic[
              If[$CellContext`moi$$ == 1, $CellContext`temp2, 
               Invisible[$CellContext`temp2]]]}]}}, Frame -> True, FrameStyle -> 
         Thickness[Tiny], Alignment -> Left, Spacings -> {Automatic, 1.5}]}, 
      "Options" :> {ControlPlacement -> Left}, "DefaultOptions" :> {}],
     ImageSizeCache->{887., {349., 355.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 ExpressionUUID -> "6aabdc19-d29b-4a1a-9795-561967acf9fd"]
}, Open  ]]
},
WindowSize->{1366, 685},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 259, 7, 155, "Title"],
Cell[1748, 44, 1435, 26, 176, "Text"],
Cell[3186, 72, 72498, 1350, 721, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature jw08vn@HBP9v#C1Wq1CzNpzc *)
